@@ -1,8 +1,8 @@
 use clap::ArgMatches;
 use dotenv::dotenv;
 use log::LevelFilter;
-use sea_orm_codegen::{EntityTransformer, OutputFile};
-use std::{error::Error, fmt::Display, fs, io::Write, path::Path, process::Command};
+use sea_orm_codegen::{EntityTransformer, OutputFile, WithSerde};
+use std::{error::Error, fmt::Display, fs, io::Write, path::Path, process::Command, str::FromStr};
 
 mod cli;
 
@@ -26,13 +26,17 @@ async fn run_generate_command(matches: &ArgMatches<'_>) -> Result<(), Box<dyn Er
             let url = args.value_of("DATABASE_URL").unwrap();
             let output_dir = args.value_of("OUTPUT_DIR").unwrap();
             let include_hidden_tables = args.is_present("INCLUDE_HIDDEN_TABLES");
-            let tables = args.values_of("TABLES").unwrap_or_default().collect::<Vec<_>>();
+            let tables = args
+                .values_of("TABLES")
+                .unwrap_or_default()
+                .collect::<Vec<_>>();
             let expanded_format = args.is_present("EXPANDED_FORMAT");
+            let with_serde = args.value_of("WITH_SERDE").unwrap();
             let filter_tables = |table: &str| -> bool {
                 if tables.len() > 0 {
                     return tables.contains(&table);
                 }
-                
+
                 true
             };
             let filter_hidden_tables = |table: &str| -> bool {
@@ -84,7 +88,8 @@ async fn run_generate_command(matches: &ArgMatches<'_>) -> Result<(), Box<dyn Er
                 panic!("This database is not supported ({})", url)
             };
 
-            let output = EntityTransformer::transform(table_stmts)?.generate(expanded_format);
+            let output = EntityTransformer::transform(table_stmts)?
+                .generate(expanded_format, WithSerde::from_str(with_serde).unwrap());
 
             let dir = Path::new(output_dir);
             fs::create_dir_all(dir)?;
